@@ -54,7 +54,7 @@ KHangMan::KHangMan()
           m_randomInt(0),
           m_scoreMultiplyingFactor(1),
           m_netScore(0),
-          m_doc(0),
+          m_doc(nullptr),
           m_helpMenu(new KHelpMenu(NULL))
 {
     setObjectName(QStringLiteral("KHangMan"));
@@ -64,7 +64,7 @@ KHangMan::KHangMan()
 
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(m_view->engine());
-    kdeclarative.setupBindings();
+    kdeclarative.setupContext();
 
     KConfigGroup windowConfig = config(QStringLiteral("Window"));
     if (windowConfig.hasKey("geometry")) {
